ApplicationRole

Enum ApplicationRole 

pub enum ApplicationRole {
    Master,
    Slave,
}
Application-layer role. Set by ModbusMaster / ModbusSlave when they take ownership of an application layer.

RTU framing differentiates request vs response by role (request and response of the same FC may have different lengths).

Variants



Master



Slave